<template>
    <div element-loading-text="数据加载中..." element-loading-spinner="el-icon-loading"
        element-loading-background="rgba(255,255,255, 0.5)" v-loading.fullscreen.lock="markLoading">
        <el-dialog v-dialogDrag title="所属“63个”重大改革项目" :visible="visible" :before-close="handleClose"
            :close-on-click-modal="false" v-if="visible" width="60%" top="6vh"
            :class="[reqLoading ? 'dialog-box' : '']">
            <div v-loading="reqLoading" element-loading-text="加载中..." element-loading-spinner="el-icon-loading"
                element-loading-background="rgba(255, 255, 255, 1)">
                <div class="search-box">
                    <el-row :gutter="24">
                        <el-col :span="7">
                            <div class="search-title">项目名称：</div>
                            <el-input v-model="queryParam.querys[0].value" placeholder="请输入内容" clearable></el-input>
                        </el-col>
                        <el-col :span="7">
                            <div class="search-title">责任单位：</div>
                            <el-input v-model="queryParam.querys[1].value" placeholder="请输入内容" clearable></el-input>
                        </el-col>
                        <el-col :span="7">
                            <div class="search-title">专项小组：</div>
                            <dict-select dictCode="zxxz" :hasDefaultOption="true" clearable
                                v-model="queryParam.querys[2].value" style="width: 100%" placeholder="请选择专项小组" />
                        </el-col>
                        <el-col :span="3">
                            <el-button icon="el-icon-search" type="primary" class="btn btn-plus" @click="handleSearch">
                                {{ this.$t('common.search') }}
                            </el-button>
                        </el-col>
                    </el-row>
                </div>
                <el-table :data="tableData" stripe style="width: 100%" height="54vh" highlight-current-row
                    @current-change="handleCurrentChange1" :header-cell-style="{ textAlign: 'center' }"
                    :cell-style="{ textAlign: 'center' }" v-loading="loading" ref="myTable">
                    <el-table-column type="index" label="序号" width="60" />
                    <el-table-column prop="projectName" label="项目名称" />
                    <el-table-column prop="unitName" label="责任单位" width="160" />
                    <el-table-column prop="groupName" label="专项小组" />
                </el-table>
            </div>
            <pagination ref="paginationPanel" style="margin-top: 10px" :pageResult="pageResult"
                @size-change="handleSizeChange" @current-change="handleCurrentChange" />
            <div slot="footer" class="dialog-footer" :style="reqLoading ? 'position: relative;z-index: -1;' : ''">
                <el-button type="primary" @click="handlSaveUpdate">确 定</el-button>
                <el-button @click="handleClose">取 消</el-button>
            </div>
        </el-dialog>
    </div>
</template>

<script>
import pagination from '@/components/pagination'
import apiLsit from '@/api/effect'
import req from '@/request.js'
import utils from '@/utils.js'
import { type } from 'jquery'
const portal = window.context.portal
export default {
    name: 'selectProjectDialog',
    components: {
        pagination,
    },
    data() {
        return {
            loading: false,
            activeName: '1',
            reqLoading: false,
            markLoading: false,
            visible: false,
            projectType: 1,
            queryParam: {
                pageBean: {
                    page: 1,
                    pageSize: 20,
                },
                querys: [
                    {
                        group: 'main',
                        operation: 'LIKE',
                        parentGroup: '',
                        property: 'project_name_',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'LIKE',
                        parentGroup: '',
                        property: 'unit_Name_',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'LIKE',
                        parentGroup: '',
                        property: 'group_name_',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'LIKE',
                        parentGroup: '',
                        property: 'status_',
                        relation: 'AND',
                        value: 1,
                    }
                ],
            },
            tableData: [],
            pageResult: {
                page: 1,
                pageSize: 20,
                total: 0,
            },
            currentRow: {},
            reformSituationId: ''
        }
    },

    created() {
    },
    methods: {
        handleCurrentChange1(currentRow, oldCurrentRow) {
            this.currentRow = currentRow
        },
        open(id) {
            this.reformSituationId = id
            this.visible = true
            this.getTableData()
        },
        getTableData() {
            this.loading = true
            this.tableData = []
            let data = JSON.parse(JSON.stringify(this.queryParam))
            apiLsit.getReformSituation(data, res => {
                this.pageResult.total = res.total
                this.tableData = res.rows || []
                this.$nextTick(() => {
                    let obj = this.tableData.find(item => item.id === this.reformSituationId)
                    this.$refs.myTable.setCurrentRow(obj)
                })
                this.loading = false
            })
        },
        handleClick(e) {
            if (e !== this.projectType) {
                this.projectType = e
                this.queryParam = {
                    pageBean: {
                        page: 1,
                        pageSize: 20,
                    },
                    querys: [
                        {
                            group: 'main',
                            operation: 'LIKE',
                            parentGroup: '',
                            property: 'project_name_',
                            relation: 'AND',
                            value: '',
                        },
                        {
                            group: 'main',
                            operation: 'LIKE',
                            parentGroup: '',
                            property: 'unit_Name_',
                            relation: 'AND',
                            value: '',
                        },
                        {
                            group: 'main',
                            operation: 'LIKE',
                            parentGroup: '',
                            property: 'group_name_',
                            relation: 'AND',
                            value: '',
                        }
                    ]
                }
                this.getTableData()
            }
        },
        handlSaveUpdate() {
            let { id, projectName } = this.currentRow
            this.$emit('handleCurrentChange2', { reformSituationId: id, reformSituationName: projectName })
            this.handleClose()
        },
        handleSearch() {
            this.getTableData()
        },
        handleCurrentChange(page) {
            this.queryParam.pageBean.page = page
            this.getTableData()
        },
        handleSizeChange(pageSize) {
            this.queryParam.pageBean.pageSize = pageSize
            this.getTableData()
        },
        // 关闭新增人员窗口
        handleClose() {
            this.projectType = 1
            this.tableData = []
            this.queryParam = {
                pageBean: {
                    page: 1,
                    pageSize: 20,
                },
                querys: [
                    {
                        group: 'main',
                        operation: 'LIKE',
                        parentGroup: '',
                        property: 'project_name_',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'LIKE',
                        parentGroup: '',
                        property: 'unit_Name_',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'LIKE',
                        parentGroup: '',
                        property: 'group_name_',
                        relation: 'AND',
                        value: '',
                    }
                ]
            }
            this.visible = false
        },
    },
}
</script>

<style lang="scss" scoped>
@import '~@/assets/css/element-variables.scss';

.tabs-box {
    display: flex;
    border-bottom: 1px solid #dcdfe6;
    margin-bottom: 10px;

    .tab-item {
        cursor: pointer;
        margin-bottom: -1px;
        padding: 5px 10px;
        font-size: 16px;
        border: 1px solid #dcdfe6;
        background: #fff;

        &:nth-child(2) {
            border-left: none;
            border-right: none;
        }

        &:nth-child(1) {
            border-top-left-radius: 5px;
        }

        &:nth-child(3) {
            border-top-right-radius: 5px;
        }

        &:hover {
            color: #409eff;
        }
    }

    .active {
        color: #409eff;
        border-bottom: none;
    }
}

.search-box {
    margin-bottom: 20px;

    .el-col {
        display: flex;
        align-items: center;

        .search-title {
            width: 120PX;
            font-size: 16px;
        }
    }
}

/deep/.el-table th>.cell,
/deep/.el-table td>.cell {
    font-size: 16px;
}

/deep/.el-table--striped .el-table__body tr.el-table__row--striped.current-row td.el-table__cell,
/deep/.el-table__body tr.current-row>td.el-table__cell {
    background-color: #9fb4ee;
}

/deep/.el-dialog__wrapper {
    overflow: hidden;
}



/deep/.el-dialog__body {
    max-height: 72vh !important;
}


.dialog-footer {
    display: flex;
    justify-content: flex-end;
}

.input_placeholder {
    /deep/input::-webkit-input-placeholder {
        color: #606266;
        font-size: 12px;
    }
}

//加载遮罩
/deep/.el-dialog__body {
    box-sizing: border-box;

    .el-loading-parent--relative {
        max-height: inherit;
    }
}

.dialog-box {
    /deep/.el-dialog__body {
        overflow: hidden;
    }
}
</style>